Engine

Struct Engine 

pub struct Engine { /* private fields */ }
An engine to compute a checksum from a string

Implementations

Source

impl Engine

pub fn new() -> Self

Construct an engine with no input

pub fn input(&mut self, s: &str) -> Result<(), Error>

Checksum some data

If this function returns an error, the Engine will be left in an indeterminate state! It is safe to continue feeding it data but the result will not be meaningful.

pub fn checksum_chars(&mut self) -> [char; 8]

Obtain the checksum of all the data thus-far fed to the engine

pub fn checksum(&mut self) -> String

Obtain the checksum of all the data thus-far fed to the engine