#[non_exhaustive]pub enum TapLeafScript<'a, Pk: MiniscriptKey, Ext: Extension> {
Miniscript(&'a Miniscript<Pk, Tap, Ext>),
}Expand description
Script at a tap leaf.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Miniscript(&'a Miniscript<Pk, Tap, Ext>)
Miniscript leaf
Implementations
sourceimpl<'a, Pk: MiniscriptKey, Ext: Extension> TapLeafScript<'a, Pk, Ext>
impl<'a, Pk: MiniscriptKey, Ext: Extension> TapLeafScript<'a, Pk, Ext>
sourcepub fn as_miniscript(&self) -> Option<&'a Miniscript<Pk, Tap, Ext>>
pub fn as_miniscript(&self) -> Option<&'a Miniscript<Pk, Tap, Ext>>
Get the Miniscript at the leaf, if it exists.
sourcepub fn version(&self) -> LeafVersion
pub fn version(&self) -> LeafVersion
Return the version of the leaf.
sourcepub fn script_size(&self) -> usize
pub fn script_size(&self) -> usize
Return the byte size of the encoded leaf script (witness script).
sourcepub fn max_satisfaction_witness_elements(&self) -> Result<usize, Error>
pub fn max_satisfaction_witness_elements(&self) -> Result<usize, Error>
Return the maximum number of witness elements used to satisfied the leaf script, including the witness script itself.
sourcepub fn max_satisfaction_size(&self) -> Result<usize, Error>
pub fn max_satisfaction_size(&self) -> Result<usize, Error>
Return the maximum byte size of a satisfying witness.
sourceimpl<'a, Pk: ToPublicKey, Ext: ParseableExt> TapLeafScript<'a, Pk, Ext>
impl<'a, Pk: ToPublicKey, Ext: ParseableExt> TapLeafScript<'a, Pk, Ext>