Function-like Expression Language

Structs

  • A token of the form x(...) or x

Traits

  • A trait for extracting a structure from a Tree representation in token form

Functions

  • Attempts to parse an expression with exactly two children
  • Parse a string as a u32, for timelocks or thresholds
  • Attempts to parse a terminal expression
  • Attempts to parse an expression with exactly one child