pub trait ArgFromStr: Sized {
    // Required method
    fn arg_from_str(s: &str, parent: &str, pos: usize) -> Result<Self, Error>;
}
Trait for parsing extension arg from String Parse an argument from s given context of parent and argument position

When parsing all allowed parameters from string, we need to restrict where the parameters can be allowed. For example, csfs() should not have a txout parameter.

All parameters that should be parsed from extensions need to implement this

Required Methods

source

fn arg_from_str(s: &str, parent: &str, pos: usize) -> Result<Self, Error>

Parse an argument from s given context of parent and argument position

Object Safety

This trait is not object safe.

Implementations on Foreign Types

source

impl ArgFromStr for Asset

source

fn arg_from_str(s: &str, parent: &str, _pos: usize) -> Result<Self, Error>

source

impl ArgFromStr for Value

source

fn arg_from_str(s: &str, parent: &str, _pos: usize) -> Result<Self, Error>

source

impl ArgFromStr for String

source

fn arg_from_str(s: &str, _parent: &str, _pos: usize) -> Result<Self, Error>

Implementors