pub trait TranslateExtParam<PArg, QArg>{
type Output;
// Required method
fn translate_ext<T, E>(&self, translator: &mut T) -> Result<Self::Output, E>
where T: ExtParamTranslator<PArg, QArg, E>;
}Expand description
Converts a descriptor using abstract extension parameters to one using concrete ones, or vice-versa
Required Associated Types
Required Methods
Sourcefn translate_ext<T, E>(&self, translator: &mut T) -> Result<Self::Output, E>where
T: ExtParamTranslator<PArg, QArg, E>,
fn translate_ext<T, E>(&self, translator: &mut T) -> Result<Self::Output, E>where
T: ExtParamTranslator<PArg, QArg, E>,
Translates a struct from one generic to another where the translations
for Pk are provided by the given ExtParamTranslator.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.