Module elements_miniscript::extensions::param
source · Expand description
Parameters to certain covenants
Enums
- All known Extension parameters/arguments
- No Extensions for elements-miniscript All the implementations for the this function are unreachable
Traits
- Trait for parsing extension arg from String Parse an argument from
sgiven context of parent and argument position - Abstract parameter to Miniscript Extension
- Trait for translating different parameter types for covenant extensions
- Converts a descriptor using abstract extension parameters to one using concrete ones, or vice-versa