Trait elements_miniscript::extensions::param::ArgFromStr
source · pub trait ArgFromStr: Sized {
// Required method
fn arg_from_str(s: &str, parent: &str, pos: usize) -> Result<Self, Error>;
}Expand description
Trait for parsing extension arg from String
Parse an argument from s given context of parent and argument position
When parsing all allowed parameters from string, we need to restrict where the parameters can be allowed. For example, csfs() should not have a txout parameter.
All parameters that should be parsed from extensions need to implement this
Required Methods
Object Safety
This trait is not object safe.