pub trait TranslateExtParam<PArg, QArg>
where PArg: ExtParam, QArg: ExtParam,
{ type Output; // Required method fn translate_ext<T, E>(&self, translator: &mut T) -> Result<Self::Output, E> where T: ExtParamTranslator<PArg, QArg, E>; }
Converts a descriptor using abstract extension parameters to one using concrete ones, or vice-versa

Required Associated Types

source

type Output

The associated output type.

Required Methods

source

fn translate_ext<T, E>(&self, translator: &mut T) -> Result<Self::Output, E>
where T: ExtParamTranslator<PArg, QArg, E>,

Translates a struct from one generic to another where the translations for Pk are provided by the given ExtParamTranslator.

Object Safety

This trait is not object safe.

Implementors

source

impl<PArg, QArg> TranslateExtParam<PArg, QArg> for CovOps<PArg>
where PArg: ExtParam, QArg: ExtParam,



type Output = CovOps<QArg>

source

impl<PArg, QArg> TranslateExtParam<PArg, QArg> for Arith<PArg>
where PArg: ExtParam, QArg: ExtParam,



type Output = Arith<QArg>

source

impl<PArg, QArg> TranslateExtParam<PArg, QArg> for CheckSigFromStack<PArg>
where PArg: ExtParam, QArg: ExtParam,

source

impl<PArg, QArg> TranslateExtParam<PArg, QArg> for Expr<PArg>
where PArg: ExtParam, QArg: ExtParam,



type Output = Expr<QArg>