pub trait TranslateExtParam<PArg, QArg>{
type Output;
// Required method
fn translate_ext<T, E>(&self, translator: &mut T) -> Result<Self::Output, E>
where T: ExtParamTranslator<PArg, QArg, E>;
}Expand description
Converts a descriptor using abstract extension parameters to one using concrete ones, or vice-versa
Required Associated Types
Required Methods
sourcefn translate_ext<T, E>(&self, translator: &mut T) -> Result<Self::Output, E>where
T: ExtParamTranslator<PArg, QArg, E>,
fn translate_ext<T, E>(&self, translator: &mut T) -> Result<Self::Output, E>where
T: ExtParamTranslator<PArg, QArg, E>,
Translates a struct from one generic to another where the translations
for Pk are provided by the given ExtParamTranslator.
Object Safety
This trait is not object safe.